@@ -29,7 +29,7 @@ def test_extract_value_lists():
     assert "checked" in value_lists
     assert [True, False] == value_lists["checked"]
     assert "dimensions" in value_lists
-    assert [{'width': 5, 'height': 10}, {'width': 10, 'height': 20}, {'width': 20, 'height': 40}] == value_lists[
+    assert [{'width': 5, 'height': 10}, {'width': 10, 'height': 20}, {'width': 20, 'height': 40}, None] == value_lists[
         "dimensions"]
     assert "color" in value_lists
     assert ['green', 'yellow', 'red'] == value_lists["color"]
@@ -418,7 +418,7 @@ def test_generate_object_type_empty():
     assert dictionary is not None
     assert "test_property" in dictionary
     assert dictionary["test_property"] is not None
-    assert len(dictionary["test_property"].keys()) is 0
+    assert len(dictionary["test_property"].keys()) == 0
 
 
 def test_generate_string_pair_enum():
